Clazz.declarePackage("J.rendersurface");
Clazz.load(["J.rendersurface.IsosurfaceRenderer"], "J.rendersurface.LcaoCartoonRenderer", null, function(){
var c$ = Clazz.declareType(J.rendersurface, "LcaoCartoonRenderer", J.rendersurface.IsosurfaceRenderer);
});
;//5.0.1-v7 Thu May 14 14:23:36 CDT 2026
