Clazz.declarePackage("JM");
Clazz.load(["JM.ProteinStructure"], "JM.Annotation", null, function(){
var c$ = Clazz.declareType(JM, "Annotation", JM.ProteinStructure);
});
;//5.0.1-v7 Thu May 14 14:23:36 CDT 2026
